# Copyright 2016 Canonical Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class OSContextError(Exception):
    """Raised when an error occurs during context generation.

    This exception is principally used in contrib.openstack.context
    """
    pass


class ServiceActionError(Exception):
    """Raised when a service action (stop/start/ etc) failed."""
    pass
